==> escudo-0.4.tbz2: escudo-0.4/chrome/escudo/content/escudo/escudo.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */

with (EscudoLib) {
  top.Escudo = {
    hash : {
      "Comptes": "deck-accounts",
      "Tags": undefined,
      "Beneficiaires": undefined,
      "*": "tabbox-op"
    },
  
    loaded: function() {
      document.getElementById("texbox-menu").focus();
      notifyObserver("refresh", null);
    },
    
    /**
     * Change the panel displayed
     * @argument obj {nsIXulElement} The select textbox to search datas
     */
    changeDisplay: function(obj) {
      var panel = undefined;
      
      if (obj.value == "") { return; }
      
      if (this.hash.hasOwnProperty(obj.value)) {
        panel = this.hash[obj.value];
        notifyObserver("refresh", null); //invalid with the account
      } else {
        var accountId = top.Escudo.Accounts.getAccountId(obj.value);
        if (accountId == undefined) {
          panel = "deck-accountToCreate";
        }else {
          panel = this.hash["*"];
        }
        notifyObserver("invalid", obj.value); //invalid with the account
      }

      try {
        var ordinal = document.getElementById(panel).getAttribute("ordinal");
        document.getElementById("deck").setAttribute("selectedIndex", ordinal - 1);
      } catch(e) {
        document.getElementById("deck").setAttribute("selectedIndex", -1);        
      }
    },
    
    startup: function() {
      var db =  Components.classes["@mozilla.org/file/directory_service;1"].
                getService(Components.interfaces.nsIProperties).
                get("ProfD", Components.interfaces.nsIFile);
      db.append("escudo.sqlite");

      //create the DB
      if (db.exists() == false) {
        var storageService = Components.classes["@mozilla.org/storage/service;1"]
                        .getService(Components.interfaces.mozIStorageService);
        var conn = storageService.openDatabase(db);
        
        //table
        conn.executeSimpleSQL('CREATE TABLE "account" ("id" INTEGER PRIMARY KEY  AUTOINCREMENT  NOT NULL , "account" TEXT NOT NULL )');
        conn.executeSimpleSQL('CREATE TABLE "j_opTag" ("operation" INTEGER NOT NULL , "tag" INTEGER NOT NULL )');
        conn.executeSimpleSQL('CREATE TABLE "operation" ("id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL ,"expense" DOUBLE NOT NULL  DEFAULT 0 ,"income" DOUBLE NOT NULL  DEFAULT 0 ,"date" DATETIME NOT NULL  DEFAULT CURRENT_DATE ,"payee" INTEGER,"account" INTEGER)');
        conn.executeSimpleSQL('CREATE TABLE "payee" ("id" INTEGER PRIMARY KEY  AUTOINCREMENT  NOT NULL , "payee" TEXT NOT NULL )');
        conn.executeSimpleSQL('CREATE TABLE "tag" ("id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL ,"tag" TEXT NOT NULL )');

        //view
        conn.executeSimpleSQL('CREATE VIEW "view_accounts" AS SELECT A.account AS account, COUNT(A.account) AS count, TOTAL(L.expense) AS expense, TOTAL(L.income) AS income, TOTAL(income - expense) AS total FROM account A LEFT JOIN operation L ON L.account = A.id GROUP BY A.account ORDER BY A.account');
        conn.executeSimpleSQL('CREATE VIEW "view_operations" AS   SELECT operation.id AS id, operation.date AS date, strftime("%s",date) * 1000 AS timestamp, operation.income AS income, operation.expense AS expense, group_concat(T.tag) as tags,P.payee as payee,A.account AS account FROM operation LEFT JOIN j_opTag J ON operation.id=J.operation LEFT JOIN tag T ON T.id = J.tag LEFT JOIN payee P ON operation.payee=P.id LEFT JOIN account A ON operation.account=A.id GROUP BY operation.id');
        conn.executeSimpleSQL('CREATE VIEW "view_payees" AS SELECT P.payee AS Payee, COUNT(P.payee) AS count, TOTAL(O.expense) AS expense, TOTAL(O.income) AS income, TOTAL(income - expense) AS total FROM payee P LEFT JOIN operation O ON O.payee = P.id GROUP BY P.payee ORDER BY P.payee');
        conn.executeSimpleSQL('CREATE VIEW "view_tags" AS SELECT T.tag AS tag, COUNT(T.tag) AS count, TOTAL(O.expense) AS expense, TOTAL(O.income) AS income, TOTAL(income - expense) AS total FROM tag T LEFT JOIN j_opTag J ON J.tag = T.id LEFT JOIN operation O ON J.operation = O.id GROUP BY T.id ORDER BY T.tag');
      }
    },
    
    /**
     * Open Import / Export dialog
     */
    openImportExport: function() {
      var param = { top: top.Escudo };
      window.openDialog("chrome://escudo/content/import-export/import-export.xul",
                        "",
                        "chrome, dialog, modal, resizable=yes",
                        param).focus();
    },

    /**
     * Exit the application.
     */
    exit: function() {
      close();
      
      var appStartup = CCSV("@mozilla.org/toolkit/app-startup;1", "nsIAppStartup");
      appStartup.quit(Components.interfaces.nsIAppStartup.eForceQuit);
      //Components.interfaces.nsIAppStartup.eForceQuit:
    }
  }

  top.Escudo.startup();
}

==> escudo-0.4.1.tbz2: escudo-0.4.1/chrome/escudo/content/escudo/escudo.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */

with (EscudoLib) {
  top.Escudo = {
    hash : { },
  
    loaded: function() {
      document.getElementById("texbox-menu").value = $STR("menu_keyIndicator");
      document.getElementById("texbox-menu").focus();
      notifyObserver("refresh", null);
      
      //fill hash
      this.hash[$STR("menu_keyIndicator")] = "deck-key-indicators";
      this.hash[$STR("menu_payees")] = undefined;
      this.hash["account"] = "tabbox-op";
      this.hash["payee"] = undefined;
    },
    
    valueType: function(obj) {
      var id = top.Escudo.Accounts.getAccountId(obj.value);
      if (id != undefined) { return { id: id, type: "account" }; }
      
      id = top.Escudo.Payees.getPayeeId(obj.value);
      if (id != undefined) { return { id: id, type: "payee" }; }

      return undefined;
    },
    
    /**
     * Change the panel displayed
     * @argument obj {nsIXulElement} The select textbox to search datas
     */
    changeDisplay: function(obj) {
      var panel = undefined;

      if (obj.value == "") { return; }

      if (this.hash.hasOwnProperty(obj.value)) {
        panel = this.hash[obj.value];
        notifyObserver("refresh", null); //invalid with the account
      } else {
        var type = this.valueType(obj);

        if (type == undefined) {
          panel = "deck-accountToCreate";
        } else {
          panel = this.hash[type.type];
        }

        notifyObserver("invalid", obj.value); //invalid with the account
      }

      try {
        var ordinal = document.getElementById(panel).getAttribute("ordinal");
        document.getElementById("deck").setAttribute("selectedIndex", ordinal - 1);
      } catch(e) {
        document.getElementById("deck").setAttribute("selectedIndex", -1);
      }
    },
    
    startup: function() {
      var db =  Components.classes["@mozilla.org/file/directory_service;1"].
                getService(Components.interfaces.nsIProperties).
                get("ProfD", Components.interfaces.nsIFile);
      db.append("escudo.sqlite");

      //create the DB
      if (db.exists() == false) {
        var storageService = Components.classes["@mozilla.org/storage/service;1"]
                        .getService(Components.interfaces.mozIStorageService);
        var conn = storageService.openDatabase(db);
        
        conn.beginTransaction();
        //table
        conn.executeSimpleSQL('CREATE TABLE "account" ("id" INTEGER PRIMARY KEY  AUTOINCREMENT  NOT NULL , "account" TEXT NOT NULL )');
        conn.executeSimpleSQL('CREATE TABLE "j_opTag" ("operation" INTEGER NOT NULL , "tag" INTEGER NOT NULL )');
        conn.executeSimpleSQL('CREATE TABLE "operation" ("id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL ,"expense" DOUBLE NOT NULL  DEFAULT 0 ,"income" DOUBLE NOT NULL  DEFAULT 0 ,"date" DATETIME NOT NULL  DEFAULT CURRENT_DATE ,"payee" INTEGER,"account" INTEGER)');
        conn.executeSimpleSQL('CREATE TABLE "payee" ("id" INTEGER PRIMARY KEY  AUTOINCREMENT  NOT NULL , "payee" TEXT NOT NULL )');
        conn.executeSimpleSQL('CREATE TABLE "tag" ("id" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL ,"tag" TEXT NOT NULL )');

        //view
        conn.executeSimpleSQL('CREATE VIEW "view_accounts" AS SELECT A.account AS account, COUNT(A.account) AS count, TOTAL(L.expense) AS expense, TOTAL(L.income) AS income, TOTAL(income - expense) AS total FROM account A LEFT JOIN operation L ON L.account = A.id GROUP BY A.account ORDER BY A.account');
        conn.executeSimpleSQL('CREATE VIEW "view_operations" AS   SELECT operation.id AS id, operation.date AS date, strftime("%s",date) * 1000 AS timestamp, operation.income AS income, operation.expense AS expense, group_concat(T.tag) as tags,P.payee as payee,A.account AS account FROM operation LEFT JOIN j_opTag J ON operation.id=J.operation LEFT JOIN tag T ON T.id = J.tag LEFT JOIN payee P ON operation.payee=P.id LEFT JOIN account A ON operation.account=A.id GROUP BY operation.id');
        conn.executeSimpleSQL('CREATE VIEW "view_payees" AS SELECT P.payee AS Payee, COUNT(P.payee) AS count, TOTAL(O.expense) AS expense, TOTAL(O.income) AS income, TOTAL(income - expense) AS total FROM payee P LEFT JOIN operation O ON O.payee = P.id GROUP BY P.payee ORDER BY P.payee');
        conn.executeSimpleSQL('CREATE VIEW "view_tags" AS SELECT T.tag AS tag, COUNT(T.tag) AS count, TOTAL(O.expense) AS expense, TOTAL(O.income) AS income, TOTAL(income - expense) AS total FROM tag T LEFT JOIN j_opTag J ON J.tag = T.id LEFT JOIN operation O ON J.operation = O.id GROUP BY T.id ORDER BY T.tag');
        conn.commitTransaction();
        conn.close();
      }
    },
    
    /**
     * Open Import / Export dialog
     */
    openImportExport: function() {
      var param = { top: top.Escudo };
      window.openDialog("chrome://escudo/content/import-export/import-export.xul",
                        "",
                        "chrome, dialog, modal, resizable=yes",
                        param).focus();
    },

    /**
     * Exit the application.
     */
    exit: function() {
      close();
      
      var appStartup = CCSV("@mozilla.org/toolkit/app-startup;1", "nsIAppStartup");
      appStartup.quit(Components.interfaces.nsIAppStartup.eForceQuit);
    }
  }

  top.Escudo.startup();
}
